==> airex_flutter_plugin-0.0.2.tar.gz: ios/Classes/AirexFlutterPlugin.m <==
#import "AirexFlutterPlugin.h"
#import <Appier/Appier.h>

@implementation AirexFlutterPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"airex_flutter_plugin"
            binaryMessenger:[registrar messenger]];
  AirexFlutterPlugin* instance = [[AirexFlutterPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {

  if ([@"getPlatformVersion" isEqualToString:call.method]) {

    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } else if ([@"QGOnStart" isEqualToString:call.method]) {

    if (call.arguments && [call.arguments isKindOfClass:[NSDictionary class]]) {
      if ([call.arguments objectForKey:@"appId"] && [call.arguments objectForKey:@"isDev"]) {

         NSString *appId = [call.arguments objectForKey:@"appId"];
         NSString *appGroup = [call.arguments objectForKey:@"appGroup"];
         bool isDev = [[call.arguments objectForKey:@"isDev"] boolValue];
         NSLog(@"appId:%@", appId);
         NSLog(@"isDev:%d", isDev);
         NSLog(@"appGroup:%@", appGroup);
         [[QGSdk getSharedInstance] onStart:appId withAppGroup:appGroup setDevProfile:isDev];
         result(nil);
         return;
       }
    }
    result(FlutterMethodNotImplemented);
  } else if ([@"QGLogEvent" isEqualToString:call.method]) {

       NSDictionary *parameters = nil;
       if ([call.arguments objectForKey:@"parameters"]) {
         NSLog(@"parameters: %@", [call.arguments objectForKey:@"parameters"]);
         parameters = [call.arguments objectForKey:@"parameters"];
       }
       if ([call.arguments objectForKey:@"eventName"]) {
         [[QGSdk getSharedInstance] logEvent:[call.arguments objectForKey:@"eventName"] withParameters:parameters];
       }
       result(nil);
  } else {
    result(FlutterMethodNotImplemented);
  }
}

@end

==> airex_flutter_plugin-0.0.3.tar.gz: ios/Classes/AirexFlutterPlugin.m <==
#import "AirexFlutterPlugin.h"
#import <Appier/Appier.h>

@implementation AirexFlutterPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"airex_flutter_plugin"
            binaryMessenger:[registrar messenger]];
  AirexFlutterPlugin* instance = [[AirexFlutterPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {

  if ([@"getPlatformVersion" isEqualToString:call.method]) {

    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } else if ([@"configure" isEqualToString:call.method]) {

    if (call.arguments && [call.arguments isKindOfClass:[NSDictionary class]]) {
      if ([call.arguments objectForKey:@"appId"] && [call.arguments objectForKey:@"isDev"]) {

         NSString *appId = [call.arguments objectForKey:@"appId"];
         NSString *senderId = [call.arguments objectForKey:@"senderId"];
         NSString *appGroup = [call.arguments objectForKey:@"appGroup"];
         bool isDev = [[call.arguments objectForKey:@"isDev"] boolValue];
         QGLog(@"appId:%@", appId);
         QGLog(@"senderId:%@", senderId);
         QGLog(@"isDev:%d", isDev);
         QGLog(@"appGroup:%@", appGroup);
         [[QGSdk getSharedInstance] onStart:appId withAppGroup:appGroup setDevProfile:isDev];
         result(nil);
         return;
       }
    }
    result(FlutterMethodNotImplemented);
  } else if ([@"QGLogEvent" isEqualToString:call.method]) {

       NSDictionary *parameters = nil;
       if ([call.arguments objectForKey:@"parameters"]) {
         NSLog(@"parameters: %@", [call.arguments objectForKey:@"parameters"]);
         parameters = [call.arguments objectForKey:@"parameters"];
       }
       if ([call.arguments objectForKey:@"eventName"]) {
         [[QGSdk getSharedInstance] logEvent:[call.arguments objectForKey:@"eventName"] withParameters:parameters];
       }
       result(nil);
  } else {
    result(FlutterMethodNotImplemented);
  }
}

@end
